summaryrefslogtreecommitdiff
path: root/inttest/tdeps1/tdeps1_rt.erl
diff options
context:
space:
mode:
Diffstat (limited to 'inttest/tdeps1/tdeps1_rt.erl')
-rw-r--r--inttest/tdeps1/tdeps1_rt.erl8
1 files changed, 4 insertions, 4 deletions
diff --git a/inttest/tdeps1/tdeps1_rt.erl b/inttest/tdeps1/tdeps1_rt.erl
index 43184c6..9f21c81 100644
--- a/inttest/tdeps1/tdeps1_rt.erl
+++ b/inttest/tdeps1/tdeps1_rt.erl
@@ -24,11 +24,11 @@ files() ->
].
run(_Dir) ->
%% Initialize the b/c apps as mercurial repos so that dependencies pull
%% properly
- HgCmd = "/bin/sh -c \"hg init && hg add && hg commit -m 'Initial commit'\"",
- {ok, _} = retest_sh:run(HgCmd, [{dir, "repo/b"}]),
- {ok, _} = retest_sh:run(HgCmd, [{dir, "repo/c"}]),
+ GitCmd = "/bin/sh -c \"git init && git add -A && git commit -a -m 'Initial commit'\"",
+ {ok, _} = retest_sh:run(GitCmd, [{dir, "repo/b"}]),
+ {ok, _} = retest_sh:run(GitCmd, [{dir, "repo/c"}]),
{ok, _} = retest_sh:run("./rebar get-deps compile", []),
@@ -24,11 +24,11 @@ files() ->
].
run(_Dir) ->
- %% Initialize the b/c apps as mercurial repos so that dependencies pull
+ %% Initialize the b/c apps as git repos so that dependencies pull
%% properly